require 'rails'

module Itam
  class Engine < ::Rails::Engine
    isolate_namespace Itam

    config.generators do |g|
      g.test_framework :rspec, :fixture => true, :views => false, :helper => true
      g.integration_tool :rspec, :fixture => true, :views => true
      g.fixture_replacement :factory_bot, :dir => 'spec/factories'
    end

    #config.autoload_paths << File.expand_path("../validators", __FILE__)

    # monkey patch via: http://pivotallabs.com/leave-your-migrations-in-your-rails-engines/
    initializer "itam.append_engine_migrations" do |app|
      unless app.root.to_s.match root.to_s
        config.paths['db/migrate'].expanded.each { |expanded_path| app.config.paths['db/migrate'] << expanded_path }
      end
    end

    # Load translations from config/locales/*.rb,yml are auto loaded.
    config.i18n.load_path += Dir[File.join(File.dirname(__FILE__), '..', '..', 'config', 'locales', '**', '*.{rb,yml}').to_s]

    # Execute local initializers for any in-house gems
    initializer "itam.load_config_initializers", :after => :load_config_initializers do |app|
      Rails.logger.info "Itam::Engine : Loading initializers"
      require File.join(File.dirname(__FILE__), '..', '..', 'config', 'in_house_gems')
      in_house_engines = ITAM_IN_HOUSE_ENGINES
      in_house_engines.each do |in_house_engine|
        initializer = File.expand_path(File.join(File.dirname(__FILE__), '..', '..', 'config', 'initializers', "#{in_house_engine.to_s}.rb"))
        Rails.logger.info "Itam::Engine : Loading '#{initializer}'"
        require initializer if File.exist? initializer
      end
    end

  end
end
